@@ -21,7 +21,7 @@ continuous and irreversible: it's possible to change the current
 time-point to write multiple notes that overlap each other.
 """
 
-__version__ = "1.0.1"
+__version__ = "1.0.2"
 
 import math, random, struct, wave
 
@@ -1868,10 +1868,14 @@ def renderTrack(track):
         _debug("  ...done.")
 
 
-def saveTrack(filename):
+def saveTrack(target):
     """
-    Saves the currently active track in .wav format in the given
-    filename. Overwrites that file if it already exists!
+    Saves the currently active track in .wav format in the named file.
+    Overwrites that file if it already exists!
+
+    If a file-like object is provided instead of a file name string, data
+    will be written directly to that object. Any cleanup for a file-like
+    object is the responsibility of the caller.
     """
     track = TRACKS[ACTIVE_TRACK]
     renderTrack(track) # make sure render is up-to-date
@@ -1880,7 +1884,8 @@ def saveTrack(filename):
         tdata = b''
     else:
         tdata = rendered[0]
-    with wave.open(filename, mode='wb') as fout:
+
+    with wave.open(target, mode='wb') as fout:
         fout.setnchannels(1)
         fout.setsampwidth(SAMPLE_WIDTH)
         fout.setframerate(SAMPLE_RATE)
